// #include <string.h>
#include <cstring>

#include "Circle2D.h"


/*!*************************************
* Create a circle given its Cartesian coordinates of the center and radius.
* @param x The x coordinate of the center.
* @param y The y coordinat of the centere
* @param r The radius.
*/
Circle2D::Circle2D(double x, double y, double r) : Point2D(x,y), rad(r)
{
}

/*!*************************************
* Create a circle of zero radius at the origin of coordinates.
*/
Circle2D::Circle2D() : Point2D(), rad(0.)
{
} /* ctor */

/*!*************************************
* Create a circle given the mid point and the radius.
* @param ctr The center point of the cricle.
* @param r The radius of the circle.
*/
Circle2D::Circle2D(const Point2D ctr, const double r) : Point2D(ctr), rad(r)
{
} /* ctor */

/*!************************************
* Check whether this circle overlaps with another one.
* @param oth The companion circle which may intersect this one.
* @return True if the circles overlap. False if they don't
*  overlap or touch only at a point.
*/
bool Circle2D::overlap(const Circle2D &oth) const
{
	/* The criterion is whether the sum of the two radii
	* is larger than the distance between the centers.
	*/
	return ( rad + oth.rad > dist(oth) ) ? true: false ;
} /* overlap */
