#ifndef ROTTRANS2D_H
#define ROTTRANS2D_H
/*
* "$Header:$"
*
*/

/*
#include <string>
#include <vector>
*/

#include "Point2D.h"

using namespace std ;

/*!*
* @brief A rotation followed by a translation.
*
* The class represents an active ccw rotation around (0,0) specified by an angle
* followed by a translation specified by its 2 delta coordinates.
*
* A rotation around another fixed point followed by a translation
* is also represented by this class, but mapped on a rotation around (0,0).
*
* Note that the two components of the transformation, the rotation
* and translation, are not commutative operations in general.
*
* Note also that the translation vector is to be interpreted in
* the original coordinate system (as indicated by *active*).
* @since 2013-07-04
* @author Richard J. Mathar
*/
class RotTrans2D {

public:
	/** The angle of rotation (radians).
	* Points are rotated ccw in the 2D plane by this angle.
	*/
	double angle ;

	/** The translation vector.
	*/
	Point2D trans ;

	/** The sine and cosine of the angle. Stored separately
	* to avoid re-computation of these two values if the
	* rotation is applied often.
	*/
	double sc[2] ;

	RotTrans2D(double ang, double tx , double ty) ;
	RotTrans2D(double ang, const Point2D & t) ;
	RotTrans2D(double ang, const Point2D & fixpt, const Point2D & t) ;
	RotTrans2D() ;
	// ~RotTrans2D() ;

	RotTrans2D inv() const ;

	Point2D apply(const Point2D &pt) const ;

protected:

private:

} ; /* RotTrans2D */

#if 0
RotTrans2D & operator*(const RotTrans2D &left, const RotTrans2D &right) ;
#endif

#endif /* ROTTRANS2D_H */

