#ifndef WINDOWSET_H
#define WINDOWSET_H
/*
* MPIA - GEIRS project
*
* "@(#) $Id$"
*
*/

#include <string>
#include <vector>

/** The CCfits library contained in
* <a href="http://heasarc.gsfc.nasa.gov/docs/software/fitsio/ccfits/"> CCfits 2.4</a>
*/
#include <CCfits/CCfits>

#include "Window.h"

using namespace std ;
using namespace CCfits ;

/** 
* @since 2012-11-08
* @author Richard J. Mathar
*/
class WindowSet {

public:
	/** Name of the input file.
	* The principal use is to look into the primary header for the SAVEARE (TRIMSIZE) keyword
	* that relocates this window in the coordinate system of the mosaic of fused chips.
	*/
	string iname ;

	/** The individual windows. At this point an ugly decision is made to collect
	* the vector of pointers to windows, because the Window class contains a pointer
	* to FITS for which no copy ctor exists, so no copy ctor for Window exists (and that
	* would be needed to avoid that at the time the dtor of ws[] goes out of scope the
	* FITS contents is deleted, although we'd like to have acess to the keywords later on...)
	*/
	// vector<Window> ws ;
	vector<Window *> ws ;

	/** Window superframe origin and extension in the coordinate system of the spliced mosaic.
	* This information is only relevant if one unites all windows in the output, but not
	* if the subareas are individually spread over extension headers.
	*/
	int trimsize[4] ;

	WindowSet(const char *fitsInname, int gp =0, int csiz = 2048) ;

	~WindowSet() ;

	void win2win(const int rotRight90, const bool flip) ;

	void rmFiles(bool verbose=false) ;
protected:

	static vector<string> ifileset(const char *fitsIname)  ;
private:

} ; /* WindowSet */

#endif /* WINDOWSET_H */
